/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

import type { IndicesStatsIndicesStats } from '@elastic/elasticsearch/lib/api/types';

/**
 * In a deployment where indices have a `green` health status, because there
 * are enough nodes to have replicas for all data indices, (i.e. deployments
 * created in Elastic Cloud), the `_stats` API returns, for any index, results
 * where the index's `primaries.docs.count` and `total.docs.count` have
 * **different** values, `4` and `8`, per this mock `_stats` API output
 */
export const mockStatsGreenIndex: Record<string, IndicesStatsIndicesStats> = {
  'auditbeat-custom-index-1': {
    uuid: 'jRlr6H_jSAysOLZ6KynoCQ',
    health: 'green',
    status: 'open',
    primaries: {
      docs: {
        count: 4,
        deleted: 0,
      },
      shard_stats: {
        total_count: 1,
      },
      store: {
        size_in_bytes: 28425,
        total_data_set_size_in_bytes: 28425,
        reserved_in_bytes: 0,
      },
      indexing: {
        index_total: 4,
        index_time_in_millis: 2,
        index_current: 0,
        index_failed: 0,
        delete_total: 0,
        delete_time_in_millis: 0,
        delete_current: 0,
        noop_update_total: 0,
        is_throttled: false,
        throttle_time_in_millis: 0,
      },
      get: {
        total: 0,
        time_in_millis: 0,
        exists_total: 0,
        exists_time_in_millis: 0,
        missing_total: 0,
        missing_time_in_millis: 0,
        current: 0,
      },
      search: {
        open_contexts: 0,
        query_total: 2,
        query_time_in_millis: 1,
        query_current: 0,
        fetch_total: 2,
        fetch_time_in_millis: 0,
        fetch_current: 0,
        scroll_total: 0,
        scroll_time_in_millis: 0,
        scroll_current: 0,
        suggest_total: 0,
        suggest_time_in_millis: 0,
        suggest_current: 0,
      },
      merges: {
        current: 0,
        current_docs: 0,
        current_size_in_bytes: 0,
        total: 0,
        total_time_in_millis: 0,
        total_docs: 0,
        total_size_in_bytes: 0,
        total_stopped_time_in_millis: 0,
        total_throttled_time_in_millis: 0,
        total_auto_throttle_in_bytes: 20971520,
      },
      refresh: {
        total: 12,
        total_time_in_millis: 29,
        external_total: 7,
        external_total_time_in_millis: 29,
        listeners: 0,
      },
      flush: {
        total: 1,
        periodic: 1,
        total_time_in_millis: 4,
      },
      warmer: {
        current: 0,
        total: 6,
        total_time_in_millis: 0,
      },
      query_cache: {
        memory_size_in_bytes: 0,
        total_count: 0,
        hit_count: 0,
        miss_count: 0,
        cache_size: 0,
        cache_count: 0,
        evictions: 0,
      },
      fielddata: {
        memory_size_in_bytes: 608,
        evictions: 0,
      },
      completion: {
        size_in_bytes: 0,
      },
      segments: {
        count: 4,
        memory_in_bytes: 0,
        terms_memory_in_bytes: 0,
        stored_fields_memory_in_bytes: 0,
        term_vectors_memory_in_bytes: 0,
        norms_memory_in_bytes: 0,
        points_memory_in_bytes: 0,
        doc_values_memory_in_bytes: 0,
        index_writer_memory_in_bytes: 0,
        version_map_memory_in_bytes: 0,
        fixed_bit_set_memory_in_bytes: 0,
        max_unsafe_auto_id_timestamp: -1,
        file_sizes: {},
      },
      translog: {
        operations: 0,
        size_in_bytes: 55,
        uncommitted_operations: 0,
        uncommitted_size_in_bytes: 55,
        earliest_last_modified_age: 170944710,
      },
      request_cache: {
        memory_size_in_bytes: 1792,
        evictions: 0,
        hit_count: 0,
        miss_count: 2,
      },
      recovery: {
        current_as_source: 0,
        current_as_target: 0,
        throttle_time_in_millis: 0,
      },
      bulk: {
        total_operations: 4,
        total_time_in_millis: 34,
        total_size_in_bytes: 852,
        avg_time_in_millis: 2,
        avg_size_in_bytes: 73,
      },
    },
    total: {
      docs: {
        count: 8,
        deleted: 0,
      },
      shard_stats: {
        total_count: 2,
      },
      store: {
        size_in_bytes: 56861,
        total_data_set_size_in_bytes: 56861,
        reserved_in_bytes: 0,
      },
      indexing: {
        index_total: 8,
        index_time_in_millis: 4,
        index_current: 0,
        index_failed: 0,
        delete_total: 0,
        delete_time_in_millis: 0,
        delete_current: 0,
        noop_update_total: 0,
        is_throttled: false,
        throttle_time_in_millis: 0,
      },
      get: {
        total: 0,
        time_in_millis: 0,
        exists_total: 0,
        exists_time_in_millis: 0,
        missing_total: 0,
        missing_time_in_millis: 0,
        current: 0,
      },
      search: {
        open_contexts: 0,
        query_total: 4,
        query_time_in_millis: 1,
        query_current: 0,
        fetch_total: 4,
        fetch_time_in_millis: 0,
        fetch_current: 0,
        scroll_total: 0,
        scroll_time_in_millis: 0,
        scroll_current: 0,
        suggest_total: 0,
        suggest_time_in_millis: 0,
        suggest_current: 0,
      },
      merges: {
        current: 0,
        current_docs: 0,
        current_size_in_bytes: 0,
        total: 0,
        total_time_in_millis: 0,
        total_docs: 0,
        total_size_in_bytes: 0,
        total_stopped_time_in_millis: 0,
        total_throttled_time_in_millis: 0,
        total_auto_throttle_in_bytes: 41943040,
      },
      refresh: {
        total: 21,
        total_time_in_millis: 58,
        external_total: 14,
        external_total_time_in_millis: 59,
        listeners: 0,
      },
      flush: {
        total: 2,
        periodic: 2,
        total_time_in_millis: 9,
      },
      warmer: {
        current: 0,
        total: 12,
        total_time_in_millis: 0,
      },
      query_cache: {
        memory_size_in_bytes: 1048,
        total_count: 0,
        hit_count: 0,
        miss_count: 0,
        cache_size: 0,
        cache_count: 0,
        evictions: 0,
      },
      fielddata: {
        memory_size_in_bytes: 608,
        evictions: 0,
      },
      completion: {
        size_in_bytes: 0,
      },
      segments: {
        count: 8,
        memory_in_bytes: 0,
        terms_memory_in_bytes: 0,
        stored_fields_memory_in_bytes: 0,
        term_vectors_memory_in_bytes: 0,
        norms_memory_in_bytes: 0,
        points_memory_in_bytes: 0,
        doc_values_memory_in_bytes: 0,
        index_writer_memory_in_bytes: 0,
        version_map_memory_in_bytes: 0,
        fixed_bit_set_memory_in_bytes: 0,
        max_unsafe_auto_id_timestamp: 1676070541751,
        file_sizes: {},
      },
      translog: {
        operations: 0,
        size_in_bytes: 110,
        uncommitted_operations: 0,
        uncommitted_size_in_bytes: 110,
        earliest_last_modified_age: 170944710,
      },
      request_cache: {
        memory_size_in_bytes: 3760,
        evictions: 0,
        hit_count: 0,
        miss_count: 4,
      },
      recovery: {
        current_as_source: 0,
        current_as_target: 0,
        throttle_time_in_millis: 0,
      },
      bulk: {
        total_operations: 8,
        total_time_in_millis: 36,
        total_size_in_bytes: 1704,
        avg_time_in_millis: 1,
        avg_size_in_bytes: 73,
      },
    },
  },
};
