/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

import type { ListItemSchema } from '@kbn/securitysolution-io-ts-list-types';

import {
  DATE_NOW,
  ELASTIC_USER,
  LIST_ID,
  LIST_ITEM_ID,
  META,
  TIE_BREAKER,
  TYPE,
  USER,
  VALUE,
} from '../../constants.mock';

export const getListItemResponseMock = (): ListItemSchema => ({
  '@timestamp': DATE_NOW,
  _version: undefined,
  created_at: DATE_NOW,
  created_by: USER,
  deserializer: undefined,
  id: LIST_ITEM_ID,
  list_id: LIST_ID,
  meta: META,
  serializer: undefined,
  tie_breaker_id: TIE_BREAKER,
  type: TYPE,
  updated_at: DATE_NOW,
  updated_by: USER,
  value: VALUE,
});

/**
 * This is useful for end to end tests where we remove the auto generated parts for comparisons
 * such as created_at, updated_at, and id.
 */
export const getListItemResponseMockWithoutAutoGeneratedValues = (
  elasticUser: string = ELASTIC_USER
): Partial<ListItemSchema> => ({
  created_by: elasticUser,
  list_id: LIST_ID,
  type: TYPE,
  updated_by: elasticUser,
  value: VALUE,
});
