/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

import type { GetResponseActionsClientConstructorOptions } from '../..';
import { getResponseActionsClient } from '../..';
import { responseActionsClientMock } from './mocks';
import { RESPONSE_ACTION_AGENT_TYPE } from '../../../../../common/endpoint/service/response_actions/constants';
import { ResponseActionsClientImpl } from './lib/base_response_actions_client';
import { UnsupportedResponseActionsAgentTypeError } from './errors';

describe('getResponseActionsClient()', () => {
  let options: GetResponseActionsClientConstructorOptions;

  beforeEach(() => {
    options = {
      ...responseActionsClientMock.createConstructorOptions(),
      connectorActions: responseActionsClientMock.createNormalizedExternalConnectorClient(),
    };
  });

  it.each(RESPONSE_ACTION_AGENT_TYPE)(
    'should return a response actions client for agentType: %s',
    (agentType) => {
      expect(getResponseActionsClient(agentType, options)).toBeInstanceOf(
        ResponseActionsClientImpl
      );
    }
  );

  it(`should throw error if agentType is not supported`, () => {
    // @ts-expect-error Argument of type "foo" is not assignable to ResponseActionAgentType
    expect(() => getResponseActionsClient('foo', options)).toThrow(
      UnsupportedResponseActionsAgentTypeError
    );
  });
});
