/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

import React from 'react';
import type { HttpSetup } from '@kbn/core/public';
import type { CspVulnerabilityFinding } from '@kbn/cloud-security-posture-common/schema/vulnerabilities/latest';
import { DetectionRuleCounter } from '../../../components/detection_rule_counter';
import {
  createDetectionRuleFromVulnerabilityFinding,
  getVulnerabilityTags,
} from '../utils/create_detection_rule_from_vulnerability';

export const VulnerabilityDetectionRuleCounter = ({
  vulnerabilityRecord,
}: {
  vulnerabilityRecord: CspVulnerabilityFinding;
}) => {
  const tags = getVulnerabilityTags(vulnerabilityRecord);

  const createVulnerabilityRuleFn = async (http: HttpSetup) =>
    await createDetectionRuleFromVulnerabilityFinding(http, vulnerabilityRecord);

  return <DetectionRuleCounter tags={tags} createRuleFn={createVulnerabilityRuleFn} />;
};
