/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

import { CodeEditor } from '@kbn/code-editor';
import React from 'react';
import { XJsonLang } from '@kbn/monaco';
import type { CspVulnerabilityFinding } from '@kbn/cloud-security-posture-common/schema/vulnerabilities/latest';
import { JSON_TAB_VULNERABILITY_FLYOUT } from '../test_subjects';
interface VulnerabilityJsonTabProps {
  vulnerabilityRecord: CspVulnerabilityFinding;
}
export const VulnerabilityJsonTab = ({ vulnerabilityRecord }: VulnerabilityJsonTabProps) => {
  return (
    <div style={{ position: 'absolute', inset: 0 }} data-test-subj={JSON_TAB_VULNERABILITY_FLYOUT}>
      <CodeEditor
        enableFindAction
        isCopyable
        allowFullScreen
        languageId={XJsonLang.ID}
        value={JSON.stringify(vulnerabilityRecord, null, 2)}
        options={{
          readOnly: true,
          lineNumbers: 'on',
          folding: true,
        }}
      />
    </div>
  );
};
