/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */
import React from 'react';
import { i18n } from '@kbn/i18n';
import { EuiPageHeader, EuiSpacer } from '@elastic/eui';
import { useCspSetupStatusApi } from '@kbn/cloud-security-posture/src/hooks/use_csp_setup_status_api';
import { useVulnerabilityDashboardApi } from '../../common/api/use_vulnerability_dashboard_api';
import { VulnerabilityTrendGraph } from './vulnerability_trend_graph';
import { NoVulnerabilitiesStates } from '../../components/no_vulnerabilities_states';
import {
  VULNERABILITY_DASHBOARD_CONTAINER,
  VULNERABILITY_DASHBOARD_PAGE_HEADER,
} from '../compliance_dashboard/test_subjects';
import { VulnerabilityStatistics } from './vulnerability_statistics';
import { CloudPosturePageTitle } from '../../components/cloud_posture_page_title';
import { CloudPosturePage } from '../../components/cloud_posture_page';
import { VulnerabilityTablePanelSection } from './vulnerability_table_panel_section';

export const VulnerabilityDashboard = () => {
  const getSetupStatus = useCspSetupStatusApi();
  const getVulnerabilityDashboard = useVulnerabilityDashboardApi();

  return (
    <CloudPosturePage query={getSetupStatus}>
      <EuiPageHeader
        data-test-subj={VULNERABILITY_DASHBOARD_PAGE_HEADER}
        bottomBorder
        pageTitle={
          <CloudPosturePageTitle
            title={i18n.translate('xpack.csp.vulnerability_dashboard.cspPageTemplate.pageTitle', {
              defaultMessage: 'Cloud Native Vulnerability Management',
            })}
          />
        }
      />
      {getSetupStatus?.data?.vuln_mgmt?.status !== 'indexed' ? (
        <NoVulnerabilitiesStates />
      ) : (
        <CloudPosturePage query={getVulnerabilityDashboard}>
          <div data-test-subj={VULNERABILITY_DASHBOARD_CONTAINER}>
            <EuiSpacer />
            <VulnerabilityStatistics />
            <EuiSpacer />
            <VulnerabilityTrendGraph />
            <EuiSpacer />
            <VulnerabilityTablePanelSection />
          </div>
        </CloudPosturePage>
      )}
    </CloudPosturePage>
  );
};
