/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

import React from 'react';
import {
  EuiButtonEmpty,
  EuiBasicTable,
  EuiSpacer,
  EuiBasicTableColumn,
  useEuiTheme,
  EuiFlexGroup,
  EuiFlexItem,
} from '@elastic/eui';
import { css } from '@emotion/react';
import {
  DASHBOARD_TABLE_TYPES,
  vulnerabilityDashboardTableContent,
} from './vulnerability_table_panel.config';
import { ChartPanel } from '../../components/chart_panel';

export interface VulnerabilityDashboardTableProps<T extends {}> {
  tableType: DASHBOARD_TABLE_TYPES;
  columns: Array<EuiBasicTableColumn<T>>;
  items: T[];
  onViewVulnerabilitiesClick: () => void;
}

export const VulnerabilityTablePanel = <T extends {}>({
  items,
  columns,
  tableType,
  onViewVulnerabilitiesClick,
}: VulnerabilityDashboardTableProps<T>) => {
  const { euiTheme } = useEuiTheme();
  const { title, viewAllLinkText } = vulnerabilityDashboardTableContent[tableType];

  return (
    <ChartPanel title={title}>
      <EuiFlexGroup direction="column" justify-content="space-between">
        <EuiFlexItem>
          <EuiBasicTable
            className="vulnerabilityTable"
            css={css`
              & .euiTableHeaderCell {
                border-bottom: ${euiTheme.border.width.thick} solid ${euiTheme.colors.darkestShade};
              }
            `}
            items={items}
            columns={columns}
          />
          <EuiSpacer size="s" />
        </EuiFlexItem>
        <EuiFlexItem grow={false}>
          <EuiButtonEmpty
            css={css`
              width: fit-content;
            `}
            iconType="search"
            onClick={onViewVulnerabilitiesClick}
            size="s"
          >
            {viewAllLinkText}
          </EuiButtonEmpty>
        </EuiFlexItem>
      </EuiFlexGroup>
    </ChartPanel>
  );
};
